import java.io.File;
import java.net.MalformedURLException;
import java.net.URI;
import java.net.URL;
import java.util.Map;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.JAXBException;
import javax.xml.namespace.QName;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import javax.xml.ws.BindingProvider;
import javax.xml.ws.Dispatch;
import javax.xml.ws.Service;
import javax.xml.ws.Service.Mode;
import javax.xml.ws.soap.SOAPBinding;

import org.jboss.ws.core.ConfigProvider;
import org.jboss.ws.core.StubExt;
import org.w3c.dom.Element;

public class WsExampleClient
{

   public static void main(String[] args) throws Exception
   {
      // create a dispatch object to invoke JBoss STS.
      Dispatch<Object> dispatch = createDispatch();

      // send the token request to JBoss STS and get the response.
      Object response = dispatch.invoke(new MessageBody());
   }

   private static Dispatch<Object> createDispatch() throws MalformedURLException, JAXBException
   {
      String targetNS = "http://org.example/";
      QName serviceName = new QName(targetNS, "WsTest");
      QName portName = new QName(targetNS, "WsTestPort");
      URL endpointAddress = new URL("http://localhost:8080/wstest");
      URL securityConfigURL = new File("jboss-wsse-client.xml").toURI().toURL();

      Service service = Service.create(serviceName);
      service.addPort(portName, SOAPBinding.SOAP11HTTP_BINDING, endpointAddress.toExternalForm());

      JAXBContext jbc = JAXBContext.newInstance(MessageBody.class);

      // create the dispatch, setting the client security configuration file.
      Dispatch<Object> dispatch = service.createDispatch(portName, jbc, Mode.PAYLOAD);
      ((ConfigProvider) dispatch).setSecurityConfig(securityConfigURL.toExternalForm());
      ((ConfigProvider) dispatch).setConfigName("Standard WSSecurity Client");

      // add the username and password to the request context.
      Map<String, Object> reqContext = dispatch.getRequestContext();

	  // disable BASIC auth which is the default.
	  reqContext.put(StubExt.PROPERTY_AUTH_TYPE, StubExt.PROPERTY_AUTH_TYPE_WSSE);
	  reqContext.put(BindingProvider.USERNAME_PROPERTY, "admin");
	  reqContext.put(BindingProvider.PASSWORD_PROPERTY, "admin");

      return dispatch;
   }

}
